summary refs log tree commit diff
path: root/pkgs/desktops
diff options
context:
space:
mode:
authorParnell Springmeyer <parnell@digitalmentat.com>2017-01-29 04:11:01 -0600
committerParnell Springmeyer <parnell@digitalmentat.com>2017-01-29 04:11:01 -0600
commit4aa0923009dac4d2307b5fe018b944180bfad6a2 (patch)
treef3a9ae5ddb0d772936dd1d53534fbe677e67a838 /pkgs/desktops
parenta8cb2afa981099889cf47185be33f4a831ff482b (diff)
downloadnixlib-4aa0923009dac4d2307b5fe018b944180bfad6a2.tar
nixlib-4aa0923009dac4d2307b5fe018b944180bfad6a2.tar.gz
nixlib-4aa0923009dac4d2307b5fe018b944180bfad6a2.tar.bz2
nixlib-4aa0923009dac4d2307b5fe018b944180bfad6a2.tar.lz
nixlib-4aa0923009dac4d2307b5fe018b944180bfad6a2.tar.xz
nixlib-4aa0923009dac4d2307b5fe018b944180bfad6a2.tar.zst
nixlib-4aa0923009dac4d2307b5fe018b944180bfad6a2.zip
Getting rid of the var indirection and using a bin path instead
Diffstat (limited to 'pkgs/desktops')
-rw-r--r--pkgs/desktops/enlightenment/enlightenment.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/desktops/enlightenment/enlightenment.nix b/pkgs/desktops/enlightenment/enlightenment.nix
index 65e3bf2d642c..3949bffaba17 100644
--- a/pkgs/desktops/enlightenment/enlightenment.nix
+++ b/pkgs/desktops/enlightenment/enlightenment.nix
@@ -42,13 +42,13 @@ stdenv.mkDerivation rec {
   # this is a hack and without this cpufreq module is not working. does the following:
   #   1. moves the "freqset" binary to "e_freqset",
   #   2. linkes "e_freqset" to enlightenment/bin so that,
   #   3. wrappers.setuid detects it and places wrappers in /run/wrappers/e_freqset,
   #   4. and finally, links /run/wrappers/e_freqset to original destination where enlightenment wants it
   postInstall = ''
     export CPUFREQ_DIRPATH=`readlink -f $out/lib/enlightenment/modules/cpufreq/linux-gnu-*`;
     mv $CPUFREQ_DIRPATH/freqset $CPUFREQ_DIRPATH/e_freqset
     ln -sv $CPUFREQ_DIRPATH/e_freqset $out/bin/e_freqset
-    ln -sv /run/wrappers/e_freqset $CPUFREQ_DIRPATH/freqset
+    ln -sv /run/wrappers/bin/e_freqset $CPUFREQ_DIRPATH/freqset
   '';
 
   meta = with stdenv.lib; {
@@ -42,13 +42,13 @@ stdenv.mkDerivation rec {
   #   1. moves the "freqset" binary to "e_freqset",
   #   2. linkes "e_freqset" to enlightenment/bin so that,
-  #   3. wrappers.setuid detects it and places wrappers in /run/wrappers/e_freqset,
-  #   4. and finally, links /run/wrappers/e_freqset to original destination where enlightenment wants it
+  #   3. wrappers.setuid detects it and places wrappers in /run/wrappers/bin/e_freqset,
+  #   4. and finally, links /run/wrappers/bin/e_freqset to original destination where enlightenment wants it
   postInstall = ''
     export CPUFREQ_DIRPATH=`readlink -f $out/lib/enlightenment/modules/cpufreq/linux-gnu-*`;